@@ -74,6 +74,12 @@ class EdfWriter(object):
     def __exit__(self, exc_type, exc_val, ex_tb):
         self.close()  # cleanup the file
 
+    def __enter__(self):
+        return self
+
+    def __del__(self):
+        self.close()
+
     def __init__(self, file_name, n_channels,
                  file_type=FILETYPE_EDFPLUS):
         """Initialises an EDF file at file_name.
@@ -283,7 +289,7 @@ class EdfWriter(object):
         -----
         This function is optional and can be called only after opening a file in writemode and before the first sample write action.
         """
-        self.technician = patient_additional
+        self.patient_additional = patient_additional
         self.update_header()
 
     def setEquipment(self, equipment):
@@ -373,7 +379,15 @@ class EdfWriter(object):
 
         Parameters
         ----------
-        birthdate:
+        birthdate: date object from datetime
+
+        Examples
+        --------
+        >>> import pyedflib
+        >>> from datetime import datetime, date
+        >>> f = pyedflib.EdfWriter('test.bdf', 1, file_type=pyedflib.FILETYPE_BDFPLUS)
+        >>> f.setBirthdate(date(1951, 8, 2))
+        >>> f.close()
 
         Notes
         -----
